import 'package:flutter/material.dart';

/// Animation Types
enum AnimationType { normal, fadeIn }

/// context: Buidlcontext conetext
/// child: Page Widget
/// AnimationType: normal or fadeIn
/// duration: Time animation
/// replacement: default value false
class CustomrouteTransitionUs {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  /// Widget with properties
  CustomrouteTransitionUs(
      {@required this.context,
      @required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false}) {
    switch (this.animation) {
      //Options in animation
      case AnimationType.normal:
        this._normalTransition();
        break;

      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
      default:
    }
  }

  /// Naviagtion normal
  void _pushPage(Route route) => Navigator.push(context, route);

  /// Navigation with replacenemt
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  /// Normal navigation transition
  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => this.child);
    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }

  /// FadeId amiantion navigation transition
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });

    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }
}
